"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const nested_map_1 = require("./nested-map");
function resolveRoutePaths(paths, importPrefix) {
    const map = {};
    const splitted = paths.map(p => p.split('/'));
    splitted.forEach(path => {
        nested_map_1.setToMap(map, pathToMapPath(path), path);
    });
    return pathMapToMeta(map, importPrefix);
}
exports.resolveRoutePaths = resolveRoutePaths;
function pathMapToMeta(map, importPrefix, parentDepth = 0) {
    if (map.value) {
        const path = map.value;
        const meta = {
            name: pathToName(path),
            path: pathToRoute(path, parentDepth),
            component: importPrefix + path.join('/')
        };
        if (map.children) {
            meta.children = pathMapChildrenToMeta(map.children, importPrefix, path.length);
        }
        return [meta];
    }
    return map.children
        ? pathMapChildrenToMeta(map.children, importPrefix, parentDepth)
        : [];
}
function pathMapChildrenToMeta(children, importPrefix, parentDepth) {
    return Array.from(children.values()).reduce((acc, value) => {
        return acc.concat(pathMapToMeta(value, importPrefix, parentDepth));
    }, []);
}
function isDynamicRoute(segment) {
    return segment[0] === '_';
}
function isOmittable(segment) {
    return segment === 'index.vue';
}
function pathToMapPath(segments) {
    const last = segments[segments.length - 1];
    return segments.slice(0, -1).concat(basename(last));
}
function pathToName(segments) {
    const last = segments[segments.length - 1];
    segments = segments.slice(0, -1).concat(basename(last));
    return segments
        .map(s => {
        return s[0] === '_' ? s.slice(1) : s;
    })
        .join('-');
}
function pathToRoute(segments, parentDepth) {
    const last = segments[segments.length - 1];
    if (isOmittable(last)) {
        segments = segments.slice(0, -1);
    }
    else {
        segments = segments.slice(0, -1).concat(basename(last));
    }
    const routeSegments = segments.slice(parentDepth).map(s => {
        return isDynamicRoute(s) ? ':' + s.slice(1) : s;
    });
    const prefix = parentDepth > 0 ? '' : '/';
    return prefix + routeSegments.join('/');
}
function basename(filename) {
    return filename.replace(/\..+?$/, '');
}
